yakumo.exception

Package yakumo :: Module exception |
[hide private]
[frames] | no frames]

# Module exception

source code

Exception classes

Classes | [hide private]
| BadRequest 400 Bad Request
| Unauthorized 401 Unauthorized
| PaymentRequired 402 Payment Required
| Forbidden 403 Forbidden
| NotFound 404 NotFound
| NoSuchAPI

Variables | [hide private]
| mapping = ``{`400`:` <class 'yakumo.exception.BadRequest'>`,` 401`:` <c`...``
| __package__ = ``'``yakumo``'``

Variables Details | [hide private]

  ### mapping Value:
      {400: <class 'yakumo.exception.BadRequest'>,
       401: <class 'yakumo.exception.Unauthorized'>,
       402: <class 'yakumo.exception.PaymentRequired'>,
       403: <class 'yakumo.exception.Forbidden'>,
       404: <class 'yakumo.exception.NotFound'>}